---
title: Spree 4.1.0
section: release_notes
order: 0
---

<a href="https://demo.spreecommerce.org"><img src="https://spreecommerce.org/wp-content/uploads/2020/01/Spree-4-1-new-ux-demo.png" /></a>

## Major/New Features

Spree 4.1 comes with a completely new mobile-first ultra-fast Storefront which you can easily customize to your brand or business requirements. The new Storefront UI was open sourced by [Spark Solutions team](https://sparksolutions.co/) built upon experiences from dozens of eCommerce projects. Special thanks go  to [Matthew Kennedy](https://github.com/MatthewKennedy) for helping out!

### Demo

Try it for yourself, check out this fashion site demo: [demo.spreecommerce.org](https://demo.spreecommerce.org/)

Explore all the newest UX features here: https://spreecommerce.org/spree-commerce-demo-explainer/

Run your own demo on Heroku (with admin panel access) here: https://github.com/spree/spree#demo

### Mobile-first Storefront

We've redesigned the Storefront UI from scratch for the mobile. Fully responsive layout with mobile and tablet devices in mind. We've implemented all the best practices making it pretty and useful for the end-users.

iPhone, Android, iPad, desktop - no matter the device, the new storefront is ready to handle all of those, out of the box!

### Easy customization

The new Spree UX is fully customizable so feel free to tweak it to your needs: the overall styling (colors, fonts, roundings, borders), header, footer, placeholder images and text, SEO settings.

To help you customize your eCommerce platfom we’ve prepared:

* [a slide deck with a step-by-step walkthrough](http://bit.ly/new-spree-ux)
* [a detailed technical how-to doc](http://bit.ly/spree-ux-customization-docs)

### Blazing fast performance

<img src="https://spreecommerce.org/wp-content/uploads/2020/03/Spree4.1_GL_homepage_mobile.png" />

Performance is one of the leading factors in eCommerce conversion rates and SEO traffic. It was one of our goals to reduce page views loading times and make the UI snappy and responsive.

We've optimized both frontend and the backend. Eliminating [n+1 queries](https://guides.rubyonrails.org/active_record_querying.html#eager-loading-associations), implementing [full page caching](https://guides.rubyonrails.org/caching_with_rails.html#conditional-get-support), improving  JavaScript evaluation time - it all resulted in amazing [Google lighthouse](https://developers.google.com/web/tools/lighthouse) scores, even on low performance hosting options and with poor mobile internet connections.

This leads to **more conversions**, **more organic search traffic**, **more sales** and more market value brought to the business owners.

### SEO and structured data

We've greatly improved SEO support by implementing [JSON-LD](https://en.wikipedia.org/wiki/JSON-LD) and [OpenGraph](https://ogp.me/) support. At the same time keeping in line with all the SEO best practices to make your storefront no 1 in search results.

### Turbolinks - single-page application without the hassle

[Turbolinks](https://github.com/turbolinks/turbolinks) makes navigating your web application faster. Get the performance benefits of a single-page application without the added complexity of a client-side JavaScript framework.

Of course, you can still combine it with React, Vue or Angular!

### Easy migration path

Just follow [Follow 4.0 to 4.1 upgrade guide](/developer/upgrades/four-dot-oh-to-four-dot-one.html) to upgrade your current store to the new UI.

### Contact

Feel free to [reach out with questions or support requests](https://sparksolutions.co/contact/),

This new Spree UX will be improved and optimized even more. We very much welcome your feedback and suggestions.

### About Spark Solutions

<a href="https://sparksolutions.co"><img src="https://sparksolutions.co/wp-content/uploads/2015/01/logo-ss-tr-221x100.png" alt="Spark Solutions"></a>

[Spark Solutions](https://sparksolutions.co/) is a software development agency specialized in Ruby on Rails, Spree Commerce and Javascript development. We’ve been leading Spree open-source efforts since 2016 as its core team. We also do client work. Our project teams consist of UX and UI designers, Software Engineers, Testers and Project Managers practicing agile project delivery. We’ll integrate our team with yours to jointly architect, deliver, maintain and scale the software products you need. You drive the project with requirements and acceptance testing and we help you deliver faster using industry-standard project management and comms best practices.

## Installation

### Add Spree gems to Gemfile

```ruby
gem 'spree', '~> 4.1'
gem 'spree_auth_devise', '~> 4.1'
gem 'spree_gateway', '~> 3.7'
```

### Run `bundle install`

**Note**: if you run into `Bundler could not find compatible versions for gem "sprockets":` error message, please run 

```bash
bundle update
```

### Use the install generators to set up Spree

```shell
rails g spree:install --user_class=Spree::User
rails g spree:auth:install
rails g spree_gateway:install
```

## Upgrade

[Follow 4.0 to 4.1 upgrade guide](/developer/upgrades/four-dot-oh-to-four-dot-one.html)

## Noteworthy changes

Please review each of the noteworthy changes to ensure your customizations or extensions are not affected. If you are affected by a change, and have any suggestions please submit a PR to help the next person!



## Full Changelog

You can view the full changes using [Github Compare](https://github.com/spree/spree/compare/4-0-stable...4-1-stable).
